@@ -5,9 +5,12 @@
 import pytest
 import numpy as np
 import os
+from copy import deepcopy
+from hera_sim.antpos import hex_array
 
-from .. import abscal, datacontainer, io
+from .. import abscal, datacontainer, io, redcal
 from ..data import DATA_PATH
+from ..utils import reverse_bl
 
 
 @pytest.mark.filterwarnings("ignore:The default for the `center` keyword has changed")
@@ -428,3 +431,51 @@ class TestDataContainerWithRealData(object):
                 assert np.all(dc.times_by_bl[0, 1] == new_times)
                 assert np.all(dc.lsts == (np.arange(10) * 2 * np.pi / 10)[new_times])
                 assert np.all(dc.lsts_by_bl[0, 1] == (np.arange(10) * 2 * np.pi / 10)[new_times])
+
+
+def test_RedDataContainer():
+    # build hexagonal array and data which tells us which baseline it comes from
+    antpos = hex_array(4, split_core=False, outriggers=0)
+    reds = redcal.get_reds(antpos, pols=['nn', 'ee', 'ne', 'en'])
+    data = datacontainer.DataContainer({red[0]: np.ones((10, 10)) * (red[0][0] + 1.0j * red[0][1]) for red in reds})
+
+    # try the several ways of constructing RedDataContainer
+    rdata1 = datacontainer.RedDataContainer(deepcopy(data), reds)
+    rdata2 = datacontainer.RedDataContainer(deepcopy(data), antpos=antpos)
+    data.antpos = antpos
+    rdata3 = datacontainer.RedDataContainer(deepcopy(data))
+    reverse_reds = [[reverse_bl(bl) for bl in red] for red in reds]
+    reverse_data = datacontainer.DataContainer({red[0]: np.ones((10, 10)) * (red[0][0] + 1.0j * red[0][1]) for red in reverse_reds})
+    rdata4 = datacontainer.RedDataContainer(deepcopy(reverse_data), reverse_reds)
+    rdata5 = datacontainer.RedDataContainer(deepcopy(reverse_data), reds)
+
+    # make sure that the data for a redundant group are being accessed from the same place in memory
+    for i, rdata in enumerate([rdata1, rdata2, rdata3, rdata4, rdata5]):
+        for red in rdata.reds:
+            for bl in red:
+                if i < 4:
+                    assert id(rdata[bl]) == id(rdata[red[0]])
+                else:
+                    assert id(rdata[reverse_bl(bl)]) == id(rdata[reverse_bl(red[0])])
+                assert(rdata.get_ubl_key(bl) in red)
+                assert(rdata.has_key(rdata.get_ubl_key(bl)))
+                assert set(rdata.get_red(bl)) == set(red)
+            val_here = deepcopy(rdata[red[0]])
+            rdata[red[0]] *= 2
+            for bl in red:
+                np.testing.assert_array_equal(val_here * 2, rdata[bl])
+
+    # test no redundancy information error
+    with pytest.raises(ValueError):
+        data = datacontainer.DataContainer({red[0]: np.ones((10, 10)) * (red[0][0] + 1.0j * red[0][1]) for red in reds})
+        rdata = datacontainer.RedDataContainer(data)
+
+    # test too much redundancy information error
+    with pytest.raises(ValueError):
+        data = datacontainer.DataContainer({red[0]: np.ones((10, 10)) * (red[0][0] + 1.0j * red[0][1]) for red in reds})
+        rdata = datacontainer.RedDataContainer(data, reds=reds, antpos=antpos)
+
+    # test error where the the data has multiple redundant baselines per group
+    with pytest.raises(ValueError):
+        data = datacontainer.DataContainer({bl: np.ones((10, 10)) * (bl[0] + 1.0j * bl[1]) for red in reds for bl in red})
+        rdata = datacontainer.RedDataContainer(data, reds)
