@@ -671,18 +671,19 @@ class Test_ReadHeraHdf5(object):
         self.uvh5_blt = os.path.join(DATA_PATH, "zen.2459114.60020.sum.downsample_transpose.uvh5")
 
     def test_basic_read(self):
-        rv = io.read_hera_hdf5([self.uvh5_1, self.uvh5_2],
-                               read_flags=False, read_nsamples=False, verbose=True,
-                               dtype=np.complex128, check=True)
-        assert 'info' in rv
-        assert 'data' in rv
-        assert 'flags' not in rv
-        assert 'nsamples' not in rv
-        assert len(rv['info']['bls']) * len(rv['info']['pols']) == len(rv['data'])
-        assert rv['info']['times'].size == np.unique(rv['info']['times']).size
-        for bl, data in rv['data'].items():
-            assert data.shape == (rv['info']['times'].size, rv['info']['freqs'].size)
-            assert data.dtype == np.complex128
+        for replace in ['.uvh5', '.new_shape.uvh5']:
+            rv = io.read_hera_hdf5([self.uvh5_1.replace('.uvh5', replace), self.uvh5_2.replace('.uvh5', replace)],
+                                   read_flags=False, read_nsamples=False, verbose=True,
+                                   dtype=np.complex128, check=True)
+            assert 'info' in rv
+            assert 'data' in rv
+            assert 'flags' not in rv
+            assert 'nsamples' not in rv
+            assert len(rv['info']['bls']) * len(rv['info']['pols']) == len(rv['data'])
+            assert rv['info']['times'].size == np.unique(rv['info']['times']).size
+            for bl, data in rv['data'].items():
+                assert data.shape == (rv['info']['times'].size, rv['info']['freqs'].size)
+                assert data.dtype == np.complex128
 
     def test_broken_read(self):
         with pytest.raises(ValueError):
@@ -716,13 +717,14 @@ class Test_ReadHeraHdf5(object):
             assert data.dtype == np.float32
 
     def test_read_allbls_poltranspose(self):
-        rv = io.read_hera_hdf5([self.uvh5_pol], dtype=np.complex128, verbose=True, check=True)
-        assert 'info' in rv
-        assert 'data' in rv
-        assert len(rv['info']['bls']) * len(rv['info']['pols']) == len(rv['data'])
-        for bl, data in rv['data'].items():
-            assert data.shape == (rv['info']['times'].size, rv['info']['freqs'].size)
-    
+        for replace in ['.uvh5', '.new_shape.uvh5']:
+            rv = io.read_hera_hdf5([self.uvh5_pol.replace('.uvh5', replace)], dtype=np.complex128, verbose=True, check=True)
+            assert 'info' in rv
+            assert 'data' in rv
+            assert len(rv['info']['bls']) * len(rv['info']['pols']) == len(rv['data'])
+            for bl, data in rv['data'].items():
+                assert data.shape == (rv['info']['times'].size, rv['info']['freqs'].size)
+
     def test_read_one_bl(self):
         rv = io.read_hera_hdf5([self.uvh5_1], verbose=True, check=True,
                                read_data=False, read_flags=False, read_nsamples=False)
@@ -744,12 +746,13 @@ class Test_ReadHeraHdf5(object):
         assert bl in rv['data']
 
     def test_read_bl_then_time_poltranpose(self):
-        rv = io.read_hera_hdf5([self.uvh5_blt], verbose=True, bls=[(24, 26)], check=True,
-                               read_data=True, read_flags=True, read_nsamples=True)
-        assert len(rv['data']) == 4
-        assert (24, 26, 'ee') in rv['data']
-        assert rv['data'][(24, 26, 'ee')].shape == (2, 1536)
-        assert len(rv['info']['times']) == 2
+        for replace in ['.uvh5', '.new_shape.uvh5']:
+            rv = io.read_hera_hdf5([self.uvh5_blt.replace('.uvh5', replace)], verbose=True, bls=[(24, 26)], check=True,
+                                   read_data=True, read_flags=True, read_nsamples=True)
+            assert len(rv['data']) == 4
+            assert (24, 26, 'ee') in rv['data']
+            assert rv['data'][(24, 26, 'ee')].shape == (2, 1536)
+            assert len(rv['info']['times']) == 2
 
 
 class Test_HERADataFastReader(object):
@@ -761,8 +764,11 @@ class Test_HERADataFastReader(object):
     def test_init(self):
         hd = io.HERADataFastReader(self.uvh5_1)
         assert hd.filepaths == [self.uvh5_1]
+        assert hd.antpos is not None
+
+        hd = io.HERADataFastReader(self.uvh5_1, read_metadata=False)
+        assert hd.filepaths == [self.uvh5_1]
         assert hd.antpos is None
-        assert hd.times_by_bl is None
 
     def test_read_data(self):
         rv = io.read_hera_hdf5([self.uvh5_1])
@@ -779,7 +785,7 @@ class Test_HERADataFastReader(object):
 
     def test_comp_to_HERAData(self):
         for infile in ([self.uvh5_1], [self.uvh5_1, self.uvh5_2], self.uvh5_h4c):
-            hd = io.HERADataFastReader(infile)
+            hd = io.HERADataFastReader(infile, read_metadata=False)
             d, f, n = hd.read(check=True)
             hd2 = io.HERAData(infile)
             d2, f2, n2 = hd2.read()
@@ -808,6 +814,29 @@ class Test_HERADataFastReader(object):
                 for ap in dc1.lsts_by_bl:
                     np.testing.assert_allclose(dc1.lsts_by_bl[ap], dc2.lsts_by_bl[ap])
 
+        # compare metadata stored in hd object
+        for infile in ([self.uvh5_1], self.uvh5_h4c):
+            hd1 = io.HERADataFastReader(infile)
+            d, f, n = hd.read(check=True)
+            hd2 = io.HERAData(infile)
+            d2, f2, n2 = hd2.read()
+            np.testing.assert_array_equal(hd1.freqs, hd2.freqs)
+            np.testing.assert_array_equal(hd1.times, hd2.times)
+            np.testing.assert_allclose(hd1.lsts, hd2.lsts)
+            np.testing.assert_array_equal(hd1.ants, hd2.ants)
+            np.testing.assert_array_equal(hd1.data_ants, hd2.data_ants)
+            np.testing.assert_array_equal(hd1.pols, hd2.pols)
+            np.testing.assert_array_equal(hd1.antpairs, hd2.antpairs)
+            np.testing.assert_array_equal(hd1.bls, hd2.bls)
+            for ant in hd1.antpos:
+                np.testing.assert_array_almost_equal(hd1.antpos[ant] - hd2.antpos[ant], 0)
+            for ant in hd1.data_antpos:
+                np.testing.assert_array_almost_equal(hd1.antpos[ant] - hd2.antpos[ant], 0)
+            for ap in hd1.times_by_bl:
+                np.testing.assert_array_equal(hd1.times_by_bl[ap], hd2.times_by_bl[ap])
+            for ap in hd1.lsts_by_bl:
+                np.testing.assert_allclose(hd1.lsts_by_bl[ap], hd2.lsts_by_bl[ap])
+
     def test_errors(self):
         hd = io.HERADataFastReader([self.uvh5_1, self.uvh5_2])
         with pytest.raises(NotImplementedError):
@@ -896,7 +925,7 @@ class Test_ReadHeraCalfits(object):
         rv = io.read_hera_calfits([self.fname_t0, self.fname_t1, self.fname_t2], ants=ants)
         assert len(rv['gains']) == 1
         assert ants[0] in rv['gains']
-        
+
         # test select on antenna numbers
         rv1 = io.read_hera_calfits([self.fname_xx, self.fname_yy], ants=(9, 10))
         rv2 = io.read_hera_calfits(self.fname_2pol, ants=(9, 10))
