@@ -167,7 +167,7 @@ class TestMethods(object):
         new_reds = om.filter_reds(reds, max_dims=2)
         ant_inds = set([ant[0] for red in new_reds for bl in red for ant in split_bl(bl)])
         assert ant_inds == set(range(0, 9))
-                
+
         # Max 3 dimensions means all 3 good rows, but keeps out the off-grid antenna
         new_reds = om.filter_reds(reds, max_dims=3)
         ant_inds = set([ant[0] for red in new_reds for bl in red for ant in split_bl(bl)])
@@ -249,7 +249,7 @@ class TestMethods(object):
     def test_find_polarity_flipped_ants(self):
         # test normal operation
         antpos = hex_array(3, split_core=False, outriggers=0)
-        reds = om.get_reds(antpos, pols=['ee'], pol_mode='1pol')
+        reds = om.get_reds(antpos, pols=['ee', 'nn'], pol_mode='2pol')
         rc = om.RedundantCalibrator(reds)
         freqs = np.linspace(.1, .2, 100)
         ants = [(ant, 'Jee') for ant in antpos]
@@ -268,7 +268,8 @@ class TestMethods(object):
         data[(0, 1, 'ee')] *= -1
         meta, g_fc = rc.firstcal(data, freqs)
         for ant in meta['polarity_flips']:
-            assert np.all([m is None for m in meta['polarity_flips'][ant]])
+            if ant[1] == 'Jee':
+                assert np.all([m is None for m in meta['polarity_flips'][ant]])
 
         # test errors
         with pytest.raises(ValueError):
@@ -385,14 +386,14 @@ class TestRedundantCalibrator(object):
         reds = om.get_reds(antpos, pols=['xx'], pol_mode='1pol')
         rc = om.RedundantCalibrator(reds)
         freqs = np.linspace(1e8, 2e8, 1024)
-        
+
         # test firstcal where the degeneracies of the phases and delays have already been removed so no abscal is necessary
         gains, true_vis, d = sim_red_data(reds, gain_scatter=0, shape=(2, len(freqs)))
         fc_delays = {ant: [[100e-9 * np.random.randn()]] for ant in gains.keys()}  # in s
         fc_delays = rc.remove_degen_gains(fc_delays)
         fc_offsets = {ant: [[.49 * np.pi * (np.random.rand() > .90)]] for ant in gains.keys()}  # the .49 removes the possibly of phase wraps that need abscal
         fc_offsets = rc.remove_degen_gains(fc_offsets)
-        fc_gains = {ant: np.reshape(np.exp(-2.0j * np.pi * freqs * delay - 1.0j * fc_offsets[ant]), (1, len(freqs))) 
+        fc_gains = {ant: np.reshape(np.exp(-2.0j * np.pi * freqs * delay - 1.0j * fc_offsets[ant]), (1, len(freqs)))
                     for ant, delay in fc_delays.items()}
         for ant1, ant2, pol in d.keys():
             d[(ant1, ant2, pol)] *= fc_gains[(ant1, split_pol(pol)[0])] * np.conj(fc_gains[(ant2, split_pol(pol)[1])])
@@ -406,7 +407,7 @@ class TestRedundantCalibrator(object):
         fc_delays = {ant: [[0 * np.random.randn()]] for ant in gains.keys()}  # in s
         fc_offsets = {ant: [[.49 * np.pi * (np.random.rand() > .90)]] for ant in gains.keys()}  # the .49 removes the possibly of phase wraps that need abscal
         fc_offsets = rc.remove_degen_gains(fc_offsets)
-        fc_gains = {ant: np.reshape(np.exp(-2.0j * np.pi * freqs * delay - 1.0j * fc_offsets[ant]), (1, len(freqs))) 
+        fc_gains = {ant: np.reshape(np.exp(-2.0j * np.pi * freqs * delay - 1.0j * fc_offsets[ant]), (1, len(freqs)))
                     for ant, delay in fc_delays.items()}
         for ant1, ant2, pol in d.keys():
             d[(ant1, ant2, pol)] *= fc_gains[(ant1, split_pol(pol)[0])] * np.conj(fc_gains[(ant2, split_pol(pol)[1])])
@@ -454,17 +455,25 @@ class TestRedundantCalibrator(object):
         w = dict([(k, 1.) for k in d.keys()])
         sol0 = dict([(k, np.ones_like(v)) for k, v in gains.items()])
         sol0.update(info.compute_ubls(d, sol0))
-        meta, sol = info.omnical(d, sol0, conv_crit=1e-12, gain=.5, maxiter=500, check_after=30, check_every=6)
-        for i in range(NANTS):
-            assert sol[(i, 'Jxx')].shape == (10, 10)
-        for bls in reds:
-            ubl = sol[bls[0]]
-            assert ubl.shape == (10, 10)
-            for bl in bls:
-                d_bl = d[bl]
-                mdl = sol[(bl[0], 'Jxx')] * sol[(bl[1], 'Jxx')].conj() * ubl
-                np.testing.assert_almost_equal(np.abs(d_bl), np.abs(mdl), decimal=10)
-                np.testing.assert_almost_equal(np.angle(d_bl * mdl.conj()), 0, decimal=10)
+
+        def wgt_func1(abs2):
+            return 1.
+
+        def wgt_func2(abs2):
+            return np.where(abs2 > 0, 5 * np.tanh(abs2 / 5) / abs2, 1)
+
+        for wgt_func in [wgt_func1, wgt_func2]:
+            meta, sol = info.omnical(d, sol0, conv_crit=1e-12, gain=.5, maxiter=500, check_after=30, check_every=6, wgt_func=wgt_func)
+            for i in range(NANTS):
+                assert sol[(i, 'Jxx')].shape == (10, 10)
+            for bls in reds:
+                ubl = sol[bls[0]]
+                assert ubl.shape == (10, 10)
+                for bl in bls:
+                    d_bl = d[bl]
+                    mdl = sol[(bl[0], 'Jxx')] * sol[(bl[1], 'Jxx')].conj() * ubl
+                    np.testing.assert_almost_equal(np.abs(d_bl), np.abs(mdl), decimal=10)
+                    np.testing.assert_almost_equal(np.angle(d_bl * mdl.conj()), 0, decimal=10)
 
     def test_omnical64(self):
         NANTS = 18
@@ -477,15 +486,22 @@ class TestRedundantCalibrator(object):
         sol0.update(info.compute_ubls(d, sol0))
         d = {k: v.astype(np.complex64) for k, v in d.items()}
         sol0 = {k: v.astype(np.complex64) for k, v in sol0.items()}
-        meta, sol = info.omnical(d, sol0, gain=.5, maxiter=500, check_after=30, check_every=6)
-        for bls in reds:
-            ubl = sol[bls[0]]
-            assert ubl.dtype == np.complex64
-            for bl in bls:
-                d_bl = d[bl]
-                mdl = sol[(bl[0], 'Jxx')] * sol[(bl[1], 'Jxx')].conj() * ubl
-                np.testing.assert_almost_equal(np.abs(d_bl), np.abs(mdl), decimal=6)
-                np.testing.assert_almost_equal(np.angle(d_bl * mdl.conj()), 0, decimal=6)
+
+        def wgt_func1(abs2):
+            return 1.
+
+        def wgt_func2(abs2):
+            return np.where(abs2 > 0, 5 * np.tanh(abs2 / 5) / abs2, 1)
+
+        for wgt_func in [wgt_func1, wgt_func2]:
+            meta, sol = info.omnical(d, sol0, gain=.5, maxiter=500, check_after=30, check_every=6, wgt_func=wgt_func)
+            for bls in reds:
+                ubl = sol[bls[0]]
+                assert ubl.dtype == np.complex64
+                for bl in bls:
+                    d_bl = d[bl]
+                    mdl = sol[(bl[0], 'Jxx')] * sol[(bl[1], 'Jxx')].conj() * ubl
+                    np.testing.assert_almost_equal(np.abs(d_bl), np.abs(mdl), decimal=6)
 
     def test_omnical128(self):
         NANTS = 18
@@ -498,15 +514,53 @@ class TestRedundantCalibrator(object):
         sol0.update(info.compute_ubls(d, sol0))
         d = {k: v.astype(np.complex128) for k, v in d.items()}
         sol0 = {k: v.astype(np.complex128) for k, v in sol0.items()}
-        meta, sol = info.omnical(d, sol0, conv_crit=1e-12, gain=.5, maxiter=500, check_after=30, check_every=6)
+
+        def wgt_func1(abs2):
+            return 1.
+
+        def wgt_func2(abs2):
+            return np.where(abs2 > 0, 5 * np.tanh(abs2 / 5) / abs2, 1)
+
+        for wgt_func in [wgt_func1, wgt_func2]:
+            meta, sol = info.omnical(d, sol0, conv_crit=1e-12, gain=.5, maxiter=500, check_after=30, check_every=6, wgt_func=wgt_func)
+            for bls in reds:
+                ubl = sol[bls[0]]
+                assert ubl.dtype == np.complex128
+                for bl in bls:
+                    d_bl = d[bl]
+                    mdl = sol[(bl[0], 'Jxx')] * sol[(bl[1], 'Jxx')].conj() * ubl
+                    np.testing.assert_almost_equal(np.abs(d_bl), np.abs(mdl), decimal=10)
+                    np.testing.assert_almost_equal(np.angle(d_bl * mdl.conj()), 0, decimal=10)
+
+    def test_omnical_outliers(self):
+        NANTS = 18 * 5  # need a largish array to retain 2 dec accuracy
+        antpos = linear_array(NANTS)
+        reds = om.get_reds(antpos, pols=['xx'], pol_mode='1pol')
+        info = om.RedundantCalibrator(reds)
+        gains, true_vis, d = sim_red_data(reds, gain_scatter=.0099999)
+        bad_bl = (4, 5, 'xx')
+        d[bad_bl] *= 30  # corrupt a measurement
+        w = dict([(k, 1.) for k in d.keys()])
+        sol0 = dict([(k, np.ones_like(v)) for k, v in gains.items()])
+        sol0.update(info.compute_ubls(d, sol0))
+
+        def wgt_func(abs2, thresh=3):
+            # return 1.  # this fails the test, proving the below is effective
+            return np.where(abs2 > 0, thresh * np.tanh(abs2 / thresh) / abs2, 1)
+
+        meta, sol = info.omnical(d, sol0, conv_crit=1e-12, gain=.5, maxiter=500, check_after=30, check_every=6, wgt_func=wgt_func)
+        for i in range(NANTS):
+            assert sol[(i, 'Jxx')].shape == (10, 10)
         for bls in reds:
             ubl = sol[bls[0]]
-            assert ubl.dtype == np.complex128
+            assert ubl.shape == (10, 10)
             for bl in bls:
+                if bl == bad_bl:
+                    continue
                 d_bl = d[bl]
                 mdl = sol[(bl[0], 'Jxx')] * sol[(bl[1], 'Jxx')].conj() * ubl
-                np.testing.assert_almost_equal(np.abs(d_bl), np.abs(mdl), decimal=10)
-                np.testing.assert_almost_equal(np.angle(d_bl * mdl.conj()), 0, decimal=10)
+                np.testing.assert_almost_equal(np.abs(d_bl), np.abs(mdl), decimal=2)
+                np.testing.assert_almost_equal(np.angle(d_bl * mdl.conj()), 0, decimal=2)
 
     def test_lincal(self):
         NANTS = 18
@@ -1132,16 +1186,16 @@ class TestRedundantCalibrator(object):
         # factor of 2 comes from the fact that all baselines go into two antennas' chisq_per_ant
         non_degen_dof_per_ant = {ant: -2 for ant in ants}
         for red in reds:
-            for bl in red:        
+            for bl in red:
                 for ant in split_bl(bl):
                     non_degen_dof_per_ant[ant] += 1.0 - 1.0 / (len(red))
         for ant in ants:
             # show that the number of degrees of freedom (i.e. expected chi^2) per antenna is always a bit larger
-            # than the number expected from just antenna and ubl DoF, but that each antenna gets some of the 
+            # than the number expected from just antenna and ubl DoF, but that each antenna gets some of the
             # degenerate DoF
             assert chisq_per_ant[ant] - non_degen_dof_per_ant[ant] < 2
             assert chisq_per_ant[ant] - non_degen_dof_per_ant[ant] > 0
-            
+
         # Test hex array (see comments on analogous test above)
         antpos = hex_array(3, split_core=False, outriggers=0)
         ants = [(ant, 'Jxx') for ant in antpos]
@@ -1155,7 +1209,7 @@ class TestRedundantCalibrator(object):
         np.testing.assert_approx_equal(np.sum(list(chisq_per_ant.values())), 2 * dof)
         non_degen_dof_per_ant = {ant: -2 for ant in ants}
         for red in reds:
-            for bl in red:        
+            for bl in red:
                 for ant in split_bl(bl):
                     non_degen_dof_per_ant[ant] += 1.0 - 1.0 / (len(red))
         for ant in ants:
@@ -1175,7 +1229,7 @@ class TestRedundantCalibrator(object):
         np.testing.assert_approx_equal(np.sum(list(chisq_per_ant.values())), 2 * dof)
         non_degen_dof_per_ant = {ant: -2 for ant in ants}
         for red in reds:
-            for bl in red:        
+            for bl in red:
                 for ant in split_bl(bl):
                     non_degen_dof_per_ant[ant] += 1.0 - 1.0 / (len(red))
         for ant in ants:
@@ -1199,7 +1253,7 @@ class TestRedundantCalibrator(object):
         n = DataContainer({bl: np.sqrt(noise_var / 2) * (np.random.randn(*vis.shape) + 1j * np.random.randn(*vis.shape)) for bl, vis in d.items()})
         noisy_data = n + DataContainer(d)
 
-        # Set up autocorrelations so that the predicted noise variance is the actual simulated noise variance 
+        # Set up autocorrelations so that the predicted noise variance is the actual simulated noise variance
         for antnum in antpos.keys():
             noisy_data[(antnum, antnum, 'xx')] = np.ones((len(times), len(freqs))) * np.sqrt(noise_var * dt * df)
         noisy_data.freqs = deepcopy(freqs)
@@ -1251,7 +1305,7 @@ class TestRedundantCalibrator(object):
         noisy_data = n + DataContainer(d)
         nsamples = DataContainer({bl: np.ones_like(d[bl], dtype=float) for bl in d})
 
-        # Set up autocorrelations so that the predicted noise variance is the actual simulated noise variance 
+        # Set up autocorrelations so that the predicted noise variance is the actual simulated noise variance
         for antnum in antpos.keys():
             noisy_data[(antnum, antnum, 'xx')] = np.ones((len(times), len(freqs))) * np.sqrt(noise_var * dt * df)
         noisy_data.freqs = deepcopy(freqs)
@@ -1293,13 +1347,13 @@ class TestRedundantCalibrator(object):
             np.testing.assert_almost_equal(np.mean(chisq_per_ant[ant]), predicted_chisq_per_ant[ant], -np.log10(.03))
 
         # make sure excluded antenna has the highest chi^2, but not inexplicably large
-        assert np.mean(cal['chisq_per_ant'][6, 'Jxx']) <= len(antpos)  
+        assert np.mean(cal['chisq_per_ant'][6, 'Jxx']) <= len(antpos)
         for ant in cal['chisq_per_ant']:
             assert np.mean(cal['chisq_per_ant'][ant]) <= np.mean(cal['chisq_per_ant'][6, 'Jxx'])
 
 
 class TestRedcalAndAbscal(object):
-    
+
     @pytest.mark.parametrize("fc_min_vis_per_ant", [16, None])
     def test_post_redcal_abscal(self, fc_min_vis_per_ant):
         '''This test shows that performing a combination of redcal and abscal recovers the exact input gains
@@ -1314,7 +1368,7 @@ class TestRedcalAndAbscal(object):
         d = DataContainer(d)
         fc_delays = {ant: 100e-9 * np.random.randn() for ant in gains.keys()}  # in s
         fc_offsets = {ant: 2 * np.pi * np.random.rand() for ant in gains.keys()}  # random phase offsets
-        fc_gains = {ant: np.reshape(np.exp(2.0j * np.pi * freqs * delay + 1.0j * fc_offsets[ant]), 
+        fc_gains = {ant: np.reshape(np.exp(2.0j * np.pi * freqs * delay + 1.0j * fc_offsets[ant]),
                                     (1, len(freqs))) for ant, delay in fc_delays.items()}
         for ant1, ant2, pol in d.keys():
             d[(ant1, ant2, pol)] *= fc_gains[(ant1, split_pol(pol)[0])] * np.conj(fc_gains[(ant2, split_pol(pol)[1])])
@@ -1340,16 +1394,16 @@ class TestRedcalAndAbscal(object):
         model.freqs = freqs
         model.times_by_bl = {bl[0:2]: np.array([2458110.18523274, 2458110.18535701]) for bl in model.keys()}
         model.antpos = antpos
-        
+
         # run abscal
         abscal_delta_gains = abscal.post_redcal_abscal(model, d_omnicaled, wgts, cal['gf_omnical'], verbose=True, phs_max_iter=200, phs_conv_crit=1e-10)
 
         # evaluate solutions, rephasing to antenna 0 as a reference
         abscal_gains = {ant: cal['g_omnical'][ant] * abscal_delta_gains[ant] for ant in cal['g_omnical']}
         refant = {'Jxx': (0, 'Jxx'), 'Jyy': (0, 'Jyy')}
-        agr = {ant: abscal_gains[ant] * np.abs(abscal_gains[refant[ant[1]]]) / abscal_gains[refant[ant[1]]] 
+        agr = {ant: abscal_gains[ant] * np.abs(abscal_gains[refant[ant[1]]]) / abscal_gains[refant[ant[1]]]
                for ant in abscal_gains.keys()}
-        tgr = {ant: true_gains[ant] * np.abs(true_gains[refant[ant[1]]]) / true_gains[refant[ant[1]]] 
+        tgr = {ant: true_gains[ant] * np.abs(true_gains[refant[ant[1]]]) / true_gains[refant[ant[1]]]
                for ant in true_gains.keys()}
         gain_errors = [agr[ant] - tgr[ant] for ant in tgr if ant[1] == 'Jxx']
         np.testing.assert_almost_equal(np.abs(gain_errors), 0, decimal=10)
@@ -1406,6 +1460,31 @@ class TestRunMethods(object):
             for val in rv['chisq'].values():
                 assert val.shape == (nTimes, nFreqs)
 
+    def test_redundantly_calibrate_with_priors(self):
+        hd = io.HERAData(os.path.join(DATA_PATH, 'zen.2458098.43124.downsample.uvh5'))
+        data, flags, nsamples = hd.read()
+        nTimes, nFreqs = len(hd.times), len(hd.freqs)
+        pol_load_list = om._get_pol_load_list(hd.pols, pol_mode='2pol')
+        ant_nums = np.unique(np.append(hd.ant_1_array, hd.ant_2_array))
+        all_reds = om.get_reds({ant: hd.antpos[ant] for ant in ant_nums}, pol_mode='2pol',
+                               pols=set([pol for pols in pol_load_list for pol in pols]))
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            rv = om.redundantly_calibrate(data, all_reds)
+            rv2 = om.redundantly_calibrate(data, all_reds, prior_firstcal=deepcopy(rv['g_firstcal']))
+            rv3 = om.redundantly_calibrate(data, all_reds, prior_firstcal=deepcopy(rv['g_firstcal']),
+                                           prior_sol={**deepcopy(rv['g_omnical']), **deepcopy(rv['v_omnical'])})
+
+        for ant in rv['g_omnical']:
+            flags = rv['gf_omnical'][ant]
+            np.testing.assert_array_equal(rv['g_omnical'][ant][~flags], rv2['g_omnical'][ant][~flags])
+            assert np.allclose(rv['g_omnical'][ant][~flags], rv3['g_omnical'][ant][~flags], atol=np.inf, rtol=1e-8)
+
+        for bl in rv['v_omnical']:
+            flags = rv['vf_omnical'][bl]
+            np.testing.assert_array_equal(rv['v_omnical'][bl][~flags], rv2['v_omnical'][bl][~flags])
+            assert np.allclose(rv['v_omnical'][bl], rv3['v_omnical'][bl], atol=np.inf, rtol=1e-8)
+
     def test_expand_omni_sol(self):
         # noise free test of dead antenna resurrection
         ex_ants = [0, 13, 2, 18]
@@ -1451,7 +1530,7 @@ class TestRunMethods(object):
                 assert not np.all(flag[t, :])
                 assert np.all(flag[t, 0:30])
                 assert np.all(flag[t, -40:])
-        
+
         hd = io.HERAData(os.path.join(DATA_PATH, 'zen.2458098.43124.downsample.uvh5'))  # test w/o partial loading
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
@@ -1511,7 +1590,7 @@ class TestRunMethods(object):
 
             hd = io.HERAData(input_data)
             cal0 = om.redcal_iteration(hd, ex_ants=[11, 50])
-            
+
             sys.stdout = sys.__stdout__
 
         for prefix, cal_here, bad_ants in [('', cal, [11, 50, 12]), ('.iter0', cal0, [11, 50])]:
