@@ -37,6 +37,8 @@ _KEY_CARDINAL_CHARS = set([c.lower() for c in _x_orientation_rep_dict('north').v
 # Define characters that appear in all Jones polarization strings. Nominally {'j'}.
 _KEY_JONES_CHARS = set([c.lower() for val in JONES_NUM2STR_DICT.values() for c in val
                        if np.all([c in v for v in JONES_NUM2STR_DICT.values()])])
+# set of characters that appear in either _KEY_CARDINAL_CHARS or _KEY_JONES_CHARS
+_KEY_POL_CHARS = _KEY_CARDINAL_CHARS | _KEY_JONES_CHARS
 
 # Get set of standard visibility polarization strings. Nominally {'rr', 'xy', 'ne', 'nn', 'lr', 'en', 'yx', 'xx', 'ee', 'rl', 'll', 'yy'}
 _VISPOLS = set([pol for pol in list(POL_STR2NUM_DICT.keys()) if polstr2num(pol) < 0 and pol == polnum2str(polstr2num(pol))])
@@ -59,7 +61,7 @@ for antpol in copy.deepcopy(_ANTPOLS):
 
 def _is_cardinal(polstr):
     '''Returns true if all characters in polstr match those in _KEY_CARDINAL_CHARS or _KEY_JONES_CHARS.'''
-    return np.all([(c.lower() in _KEY_CARDINAL_CHARS) or (c.lower() in _KEY_JONES_CHARS) for c in polstr])
+    return set(polstr.lower()).issubset(_KEY_POL_CHARS)
 
 
 def _comply_antpol(antpol):
@@ -542,14 +544,14 @@ def LST2JD(LST, start_jd, allow_other_jd=False, lst_branch_cut=0.0, latitude=-30
     LST : type=float or array-like, local apparent sidereal time [radians]
 
     start_jd : type=int, integer julian day to use as starting point for LST2JD conversion
-    
-    allow_other_jd : type=bool, ensure that the lst_branch_cut falls on start_jd but allow 
+
+    allow_other_jd : type=bool, ensure that the lst_branch_cut falls on start_jd but allow
                      LSTs to correspond to previous or subsequent days if necessary
-        
-    lst_branch_cut : type=float, LST that must fall during start_jd even when allow_other_jd 
+
+    lst_branch_cut : type=float, LST that must fall during start_jd even when allow_other_jd
                      is True. Used as the starting point starting point where LSTs below this
                      value map to later JDs than this LST [radians]
-    
+
     latitude : type=float, degrees North of observer, default=HERA latitude
 
     longitude : type=float, degrees East of observer, default=HERA longitude
@@ -570,7 +572,7 @@ def LST2JD(LST, start_jd, allow_other_jd=False, lst_branch_cut=0.0, latitude=-30
 
     # increase LSTs so no values fall below the branch cut (avoiding wraps in interpolation)
     while np.any(LST < lst_branch_cut):
-        LST[LST < lst_branch_cut] += 2 * np.pi  
+        LST[LST < lst_branch_cut] += 2 * np.pi
 
     # create interpolator for a given start date that puts the lst_branch_cut on start_jd
     jd_grid = start_jd + np.linspace(-1, 2, 31)  # include previous and next days
@@ -585,10 +587,10 @@ def LST2JD(LST, start_jd, allow_other_jd=False, lst_branch_cut=0.0, latitude=-30
             jd_grid += unt.sday.to(unt.day)
         else:
             break
-        
+
     # interpolate
     jd_array = interpolator(LST)
-    
+
     # Enforce single JD if desired
     if not allow_other_jd:
         while True:
